@@ -249,11 +249,14 @@ class MutwoVolumeToAbjadAttachmentDynamicConverter(converters_abc.Converter):
 
     def convert(
         self, volume_to_convert: parameters.abc.Volume
-    ) -> abjad_attachments.Dynamic:
+    ) -> typing.Optional[abjad_attachments.Dynamic]:
         if not isinstance(volume_to_convert, parameters.volumes.WesternVolume):
-            volume_to_convert = parameters.volumes.WesternVolume.from_amplitude(
-                volume_to_convert.amplitude
-            )
+            if volume_to_convert.amplitude > 0:
+                volume_to_convert = parameters.volumes.WesternVolume.from_amplitude(
+                    volume_to_convert.amplitude
+                )
+            else:
+                return None
         return abjad_attachments.Dynamic(dynamic_indicator=volume_to_convert.name)
 
 
@@ -536,6 +539,7 @@ class SequentialEventToQuantizedAbjadContainerConverter(converters_abc.Converter
         attack_point_optimizer: typing.Optional[
             nauert.AttackPointOptimizer
         ] = nauert.MeasurewiseAttackPointOptimizer(),
+        search_tree: typing.Optional[nauert.SearchTree] = None,
     ):
         if duration_unit == "miliseconds":
             # warning for not well implemented miliseconds conversion
@@ -573,7 +577,7 @@ class SequentialEventToQuantizedAbjadContainerConverter(converters_abc.Converter
         self._tempo_envelope = tempo_envelope
         self._attack_point_optimizer = attack_point_optimizer
         self._q_schema = SequentialEventToQuantizedAbjadContainerConverter._make_q_schema(
-            self._time_signatures
+            self._time_signatures, search_tree
         )
 
     # ###################################################################### #
@@ -617,8 +621,9 @@ class SequentialEventToQuantizedAbjadContainerConverter(converters_abc.Converter
             related_abjad_leaves_per_simple_event[index_of_previous_q_event].append(
                 tuple(indices)
             )
-        else:
-            related_abjad_leaves_per_simple_event.append([tuple(indices)])
+        # skip leaves without any links
+        # else:
+        #     related_abjad_leaves_per_simple_event.append([tuple(indices)])
 
         has_tie = abjad.get.has_indicator(abjad_leaf, abjad.Tie)
 
@@ -715,17 +720,22 @@ class SequentialEventToQuantizedAbjadContainerConverter(converters_abc.Converter
 
     @staticmethod
     def _make_q_schema(
-        time_signatures: typing.Tuple[abjad.TimeSignature, ...]
+        time_signatures: typing.Tuple[abjad.TimeSignature, ...],
+        search_tree: typing.Optional[nauert.SearchTree],
     ) -> nauert.QSchema:
         formated_time_signatures = []
         for time_signature in time_signatures:
             formated_time_signatures.append({"time_signature": time_signature})
 
-        return nauert.MeasurewiseQSchema(
-            *formated_time_signatures,
-            use_full_measure=True,
-            tempo=abjad.MetronomeMark((1, 4), 60),
-        )
+        keyword_arguments = {
+            "use_full_measure": True,
+            "tempo": abjad.MetronomeMark((1, 4), 60),
+        }
+
+        if search_tree:
+            keyword_arguments.update({"search_tree": search_tree})
+
+        return nauert.MeasurewiseQSchema(*formated_time_signatures, **keyword_arguments)
 
     # ###################################################################### #
     #                         private methods                                #
@@ -856,11 +866,16 @@ class SequentialEventToDurationLineBasedQuantizedAbjadContainerConverter(
         attack_point_optimizer: typing.Optional[
             nauert.AttackPointOptimizer
         ] = nauert.MeasurewiseAttackPointOptimizer(),
+        search_tree: typing.Optional[nauert.SearchTree] = None,
         duration_line_minimum_length: int = 6,
         duration_line_thickness: int = 3,
     ):
         super().__init__(
-            time_signatures, duration_unit, tempo_envelope, attack_point_optimizer
+            time_signatures,
+            duration_unit,
+            tempo_envelope,
+            attack_point_optimizer,
+            search_tree,
         )
         self._duration_line_minimum_length = duration_line_minimum_length
         self._duration_line_thickness = duration_line_thickness
@@ -912,32 +927,33 @@ class SequentialEventToDurationLineBasedQuantizedAbjadContainerConverter(
         is_first = True
 
         for abjad_leaves_indices in related_abjad_leaves_per_simple_event:
-            first_element = tools.get_nested_item_from_indices(
-                abjad_leaves_indices[0], quanitisized_abjad_leaves
-            )
-            if is_first:
-                self._prepare_first_element(first_element)
-                is_first = False
-
-            is_active = bool(abjad.get.pitches(first_element))
-            if is_active:
-                if len(abjad_leaves_indices) > 1:
-                    abjad.detach(abjad.Tie(), first_element)
-
-                abjad.attach(
-                    abjad.LilyPondLiteral("\\-", format_slot="after"), first_element
+            if abjad_leaves_indices:
+                first_element = tools.get_nested_item_from_indices(
+                    abjad_leaves_indices[0], quanitisized_abjad_leaves
                 )
+                if is_first:
+                    self._prepare_first_element(first_element)
+                    is_first = False
 
-                for indices in abjad_leaves_indices[1:]:
-                    element = tools.get_nested_item_from_indices(
-                        indices, quanitisized_abjad_leaves
-                    )
-                    tools.set_nested_item_from_indices(
-                        indices,
-                        quanitisized_abjad_leaves,
-                        abjad.Skip(element.written_duration),
+                is_active = bool(abjad.get.pitches(first_element))
+                if is_active:
+                    if len(abjad_leaves_indices) > 1:
+                        abjad.detach(abjad.Tie(), first_element)
+
+                    abjad.attach(
+                        abjad.LilyPondLiteral("\\-", format_slot="after"), first_element
                     )
 
+                    for indices in abjad_leaves_indices[1:]:
+                        element = tools.get_nested_item_from_indices(
+                            indices, quanitisized_abjad_leaves
+                        )
+                        tools.set_nested_item_from_indices(
+                            indices,
+                            quanitisized_abjad_leaves,
+                            abjad.Skip(element.written_duration),
+                        )
+
     def convert(
         self, sequential_event_to_convert: events.basic.SequentialEvent
     ) -> typing.Tuple[
@@ -1186,11 +1202,13 @@ class SequentialEventToAbjadVoiceConverter(converters_abc.Converter):
     def _volume_to_abjad_attachment(
         self, volume: parameters.abc.Volume
     ) -> typing.Dict[str, abjad_attachments.AbjadAttachment]:
-        return {
-            "dynamic": self._mutwo_volume_to_abjad_attachment_dynamic_converter.convert(
-                volume
-            )
-        }
+        abjad_attachment_dynamic = self._mutwo_volume_to_abjad_attachment_dynamic_converter.convert(
+            volume
+        )
+        if abjad_attachment_dynamic:
+            return {"dynamic": abjad_attachment_dynamic}
+        else:
+            return {}
 
     def _get_tempo_attachments_for_quantized_abjad_leaves(
         self, abjad_voice: abjad.Voice,
@@ -1333,7 +1351,10 @@ class SequentialEventToAbjadVoiceConverter(converters_abc.Converter):
 
         # TODO(Add option: no dynamic indicator if there aren't any pitches)
         try:
-            volume = self._simple_event_to_volume(simple_event)
+            if pitches:
+                volume = self._simple_event_to_volume(simple_event)
+            else:
+                volume = parameters.volumes.DirectVolume(0)
         except AttributeError:
             volume = parameters.volumes.DirectVolume(0)
             pitches = []
@@ -1373,7 +1394,7 @@ class SequentialEventToAbjadVoiceConverter(converters_abc.Converter):
             )
             if leaf_class == abjad.Note:
                 # skip don't have note heads
-                if hasattr(abjad_leaf, 'note_head'):
+                if hasattr(abjad_leaf, "note_head"):
                     abjad_leaf.note_head._written_pitch = abjad_pitches[0]
 
             else:
